@@ -10,17 +10,18 @@ import re
 ##############################################################################
 
 
-def get_install_prefix_from_config_cmake():
+def get_install_prefix_from_config_cmake(isolated=False):
     '''
       Parse the config.cmake looking for the CMAKE_INSTALL_PREFIX
     '''
-    print("get_underlays_list_from_config_cmaked")
+    suffix = "_isolated" if isolated else ""
+    print("get_underlays_list_from_config_cmake")
     f = open('config.cmake')
     for line in f:
         # use .*? where ? makes the match non-greedy
         m = re.search('^set\(CMAKE_INSTALL_PREFIX "(.*?)"', line)
         if m:
-            return m.group(1)
+            return m.group(1) + suffix
     return ""
 
 
